@@ -2,6 +2,7 @@ import copy
 import hashlib
 import json
 import logging
+import os
 import random
 import re
 import traceback
@@ -224,6 +225,9 @@ class FolioClient:
         }
         if personal_access_token:
             github_headers["authorization"] = f"token {personal_access_token}"
+        elif os.environ.get("GITHUB_TOKEN"):
+            logging.info("Using GITHB_TOKEN environment variable for Gihub API Access")
+            github_headers["authorization"] = f"token {os.environ.get('GITHUB_TOKEN')}"
         latest_path = f"https://api.github.com/repos/{owner}/{repo}/releases/latest"
         req = requests.get(latest_path, headers=github_headers)
         req.raise_for_status()
@@ -232,7 +236,7 @@ class FolioClient:
         latest_tag = latest["tag_name"]
         latest_path = f"https://raw.githubusercontent.com/{owner}/{repo}/{latest_tag}/{filepath}"
         # print(latest_path)
-        req = requests.get(latest_path)
+        req = requests.get(latest_path, headers=github_headers)
         req.raise_for_status()
         if filepath.endswith("json"):
             return json.loads(req.text)
@@ -252,9 +256,9 @@ class FolioClient:
                 (l["id"] for l in self.locations if location_code.strip() == l["code"]),
                 (
                     next(
-                        l["id"]
-                        for l in self.locations
-                        if l["code"] in ["catch_all", "default", "Default", "ATDM"]
+                        loc["id"]
+                        for loc in self.locations
+                        if loc["code"] in ["catch_all", "default", "Default", "ATDM"]
                     )
                 ),
             )
